{
  config,
  pkgs,
  lib,
  ...
}: let
  cfg = config.services.vm_nixarr;
in {
  options.services.vm_nixarr = {
    enable = lib.mkEnableOption "Enable minimal config";
  };
  config = lib.mkIf cfg.enable {
    age.secrets = {
      nixarr-lapi-key = {
        file = ../../secrets/nixarr-lapi-key.age;
        owner = "crowdsec";
      };
    };
    fileSystems."/downloads" = {
      device = "192.168.1.125:/BIGDATA";
      fsType = "nfs";
      options = [
        "x-systemd.automount"
        "noauto"
      ];
    };
    services = {
      crowdsec = {
        hub.collections = [
          "LePresidente/gitea"
        ];
        settings.lapi.credentialsFile = "${config.age.secrets.nixarr-lapi-key.path}";
        localConfig = {
          acquisitions = [
            {
              source = "journalctl";
              journalctl_filter = [ "_SYSTEMD_UNIT=radarr.service" ];
              labels = {
                type = "syslog";
              };
            }
          ];
        };
      };
      prowlarr = {
        enable = true;
        openFirewall = true;
      };
      bazarr = {
        enable = true;
        openFirewall = true;
      };
      sonarr = {
        enable = true;
        openFirewall = true;
      };
      radarr = {
        enable = true;
        openFirewall = true;
      };
      jellyseerr = {
        enable = true;
        openFirewall = true;
      };
    };
    networking = {
      firewall.allowedTCPPorts = [3000 9708];
      extraHosts = ''
        188.114.96.2 www.yggtorrent.top
        188.114.97.2 www.yggtorrent.top
      '';
    };
  };
}
